## LangChain Templates
This section of the project has stable PoC Ready various RAG codes starting from simple to advanced techniques along with the LangGraph and LangSmith.
Every LangChain code base has its own readme.md for more specific guidance.
Go to a specific project and follow the respective readme.md fore more details.
As a backend layer all the LangChain projects uses Qdrant and for LLM the project templates use Ollama.
These can be just replaced by their substitutes to make the code working normally.